@@ -37,6 +37,14 @@ def serialize_value(value: Any) -> Any:
                 f'Multiple serializers ({compatible_serializers}) found '
                 f'for {value} of type {type(value)}')
         serializer = compatible_serializers[0]
+        if not isinstance(value, Process):
+            # We don't warn for processes because since their types
+            # based on their subclasses, it's not possible to avoid
+            # searching through the serializers.
+            warnings.warn(
+                f'Searched through serializers to find {serializer} '
+                f'for a value of type {type(value)}. This is '
+                f'inefficient.')
     return serializer.serialize(value)
 
 
@@ -66,7 +74,8 @@ class IdentitySerializer(Serializer):  # pylint: disable=abstract-method
     '''Serializer for base types that get serialized as themselves.'''
 
     def __init__(self) -> None:
-        super().__init__(exclusive_types=(int, float, bool, str))
+        super().__init__(
+            exclusive_types=(int, float, bool, str, type(None)))
 
     def can_serialize(self, data: Any) -> bool:
         if (
@@ -188,8 +197,8 @@ class NumpyScalarSerializer(Serializer):
             np.bool_,
             np.int8, np.int16, np.int32, np.int64,
             np.uint8, np.uint16, np.uint32, np.uint64,
-            np.float16, np.float32, np.float64, np.float128,
-            np.complex64, np.complex128, np.complex256,
+            np.float16, np.float32, np.float64,
+            np.complex64, np.complex128,
         ))
 
     @staticmethod
@@ -381,6 +390,10 @@ class FunctionSerializer(Serializer):
     Currently only supports serialization (for emitting simulation
     configs).
     """
+    def __init__(self) -> None:
+        super().__init__(exclusive_types=(
+            type(serialize_value),  # Get the function type.
+        ))
     def can_serialize(self, data: Any) -> bool:
         return callable(data)
 
