@@ -3,10 +3,11 @@ import uuid
 import logging as log
 
 from vivarium.core.process import (
-    Step
+    Step,
+    ParallelProcess,
 )
 from vivarium.core.composer import Composer
-from vivarium.core.composition import (
+from vivarium.core.directories import (
     PROCESS_OUT_DIR,
 )
 from vivarium.core.engine import (
@@ -101,7 +102,9 @@ class MetaDivision(Step):
 class ToyAgent(Composer):
     defaults = {
         'exchange': {'uptake_rate': 0.1},
-        'agents_path': ('..', '..', 'agents')}
+        'agents_path': ('..', '..', 'agents'),
+        'parallel': False,
+    }
 
     def generate_processes(self, config):
         agent_id = config['agent_id']
@@ -109,6 +112,8 @@ class ToyAgent(Composer):
             {},
             agent_id=agent_id,
             composer=self)
+        config['exchange']['_parallel'] = config['parallel']
+        division_config['_parallel'] = config['parallel']
 
         return {
             'exchange': ExchangeA(config['exchange']),
@@ -127,8 +132,24 @@ class ToyAgent(Composer):
         }
 
 
-def test_division():
-    agent_id = '1'
+def _get_toy_experiment(agent_id, time_divide, time_total, parallel):
+    timeline = [
+        (0, {('agents', agent_id, 'global', 'divide'): False}),
+        (time_divide, {('agents', agent_id, 'global', 'divide'): True}),
+        (time_total, {})]
+
+    # create the processes
+    timeline_process = TimelineProcess({'timeline': timeline})
+    agent = ToyAgent({'agent_id': agent_id, 'parallel': parallel})
+
+    # compose
+    composite = agent.generate(path=('agents', agent_id))
+    composite.merge(
+        processes={'timeline': timeline_process},
+        topology={'timeline': {
+            'global': ('global',),
+            'agents': ('agents',)}},
+    )
 
     # initial state
     initial_state = {
@@ -143,31 +164,21 @@ def test_division():
         }
     }
 
-    # timeline triggers division
-    time_divide = 5
-    time_total = 10
-    timeline = [
-        (0, {('agents', agent_id, 'global', 'divide'): False}),
-        (time_divide, {('agents', agent_id, 'global', 'divide'): True}),
-        (time_total, {})]
-
-    # declare the hierarchy
-    timeline = TimelineProcess({'timeline': timeline})
-    agent = ToyAgent({'agent_id': agent_id})
-
-    composite = agent.generate(path=('agents', agent_id))
-    composite.merge(
-        processes={'timeline': timeline},
-        topology={'timeline': {
-            'global': ('global',),
-            'agents': ('agents',)}},
-        state=initial_state
-    )
-
     # configure experiment
     experiment = Engine(
         composite=composite,
+        initial_state=initial_state
     )
+    return experiment
+
+
+
+def test_division():
+    agent_id = '1'
+    time_divide = 5
+    time_total = 10
+    experiment = _get_toy_experiment(
+        agent_id, time_divide, time_total, False)
 
     # run simulation
     experiment.update(time_total)
@@ -184,6 +195,37 @@ def test_division():
     return output
 
 
+def test_division_parallel():
+    agent_id = '1'
+    time_divide = 5
+    time_total = 10
+    experiment = _get_toy_experiment(
+        agent_id, time_divide, time_total, True)
+
+    # run simulation
+    experiment.update(time_total)
+    for agent in experiment.state.get_path(('agents',)).inner:
+        assert isinstance(
+            experiment.processes['agents'][agent]['exchange'],
+            ParallelProcess,
+        )
+        assert isinstance(
+            experiment.state.get_path(('agents', agent, 'exchange')).value,
+            ParallelProcess,
+        )
+    output = experiment.emitter.get_data()
+    experiment.end()
+
+    # external starts at 1, goes down until death, and then back up
+    # internal does the inverse
+    assert list(output[time_divide]['agents'].keys()) == [agent_id]
+    assert agent_id not in list(output[time_divide + 1]['agents'].keys())
+    assert len(output[time_divide]['agents']) == 1
+    assert len(output[time_divide + 1]['agents']) == 2
+
+    return output
+
+
 def run_division():
     out_dir = os.path.join(PROCESS_OUT_DIR, NAME)
     os.makedirs(out_dir, exist_ok=True)
