@@ -11,12 +11,11 @@ from vivarium.core.process import (
     Deriver,
 )
 from vivarium.core.composer import Composer
-from vivarium.core.composition import (
-    simulate_composer,
-    PROCESS_OUT_DIR,
-)
+from vivarium.core.directories import PROCESS_OUT_DIR
+from vivarium.core.engine import Engine
 from vivarium.plots.simulation_output import plot_simulation_output
 from vivarium.composites.toys import ExchangeA
+from vivarium.processes.timeline import TimelineProcess
 
 NAME = 'swap_compartment'
 
@@ -129,17 +128,10 @@ class ToyLivingCompartment(Composer):
 def test_death():
     agent_id = '1'
 
-    # make the compartment
+    # make the composite
     compartment = ToyLivingCompartment({
         'agent_id': agent_id})
 
-    # initial state
-    initial_state = {
-        'agents': {
-            agent_id: {
-                'external': {'A': 1},
-                'trigger': False}}}
-
     # timeline turns death on
     time_dead = 5
     time_total = 10
@@ -147,16 +139,30 @@ def test_death():
         (0, {('agents', agent_id, 'dead'): False}),
         (time_dead, {('agents', agent_id, 'dead'): True}),
         (time_total, {})]
+    timeline_process = TimelineProcess({'timeline': timeline})
+
+    # compose
+    composite = compartment.generate(path=('agents', agent_id))
+    composite.merge(
+        processes={'timeline': timeline_process},
+        topology={'timeline': {
+            'global': ('global',),
+            'agents': ('agents',)}},
+    )
+
+    # initial state
+    initial_state = {
+        'agents': {
+            agent_id: {
+                'external': {'A': 1},
+                'trigger': False}}}
 
     # simulate
-    settings = {
-        'outer_path': ('agents', agent_id),
-        'timeline': {
-            'timeline': timeline},
-        'initial_state': initial_state}
-    output = simulate_composer(
-        compartment,
-        settings)
+    sim = Engine(
+        composite=composite,
+        initial_state=initial_state)
+    sim.update(time_total)
+    output = sim.emitter.get_timeseries()
 
     # external starts at 1, goes down until death, and then back up
     # internal does the inverse
